Module dioxus_html::document

source ·

Re-exports

Modules

  • Modifying the Head

Structs

  • The default No-Op document
  • A wrapper around the target platform’s evaluator that lets you send and receive data from JavaScript spawned by eval.

Enums

  • Represents an error when evaluating JavaScript

Traits

  • A provider for document-related functionality. By default most methods are driven through [eval].
  • The platform’s evaluator.

Functions

  • Get the document provider for the current platform or a no-op provider if the platform doesn’t document functionality.
  • Communicating with JavaScript
  • Get a struct that can execute any JavaScript.