Function dioxus_html::document::head::Meta

source ·
pub fn Meta(props: MetaProps) -> Element
Render a meta tag into the head of the page.

Example

fn RedirectToDioxusHomepageWithoutJS() -> Element {
    rsx! {
        // You can use the meta component to render a meta tag into the head of the page
        // This meta tag will redirect the user to the dioxuslabs homepage in 10 seconds
        Meta {
            http_equiv: "refresh",
            content: "10;url=https://dioxuslabs.com",
        }
    }
}

Any updates to the props after the first render will not be reflected in the head.