SelectionData

Struct SelectionData 

pub struct SelectionData { /* private fields */ }

Implementations

Source

impl SelectionData

pub fn new(inner: impl HasSelectionData + 'static) -> Self

Create a new SelectionData

pub fn selection(&self) -> Option<TextSelection>

The selection inside a text control.

This is only populated for event targets that expose the text-control selection APIs, such as input and textarea on the web. Some selection events, notably selectstart, can also fire when selecting normal document text. Those document selections are exposed by browser APIs like document.getSelection() and intentionally return None here.

pub fn downcast<T: 'static>(&self) -> Option<&T>

Downcast this event to a concrete event type