Type Alias PixelsSize

pub type PixelsSize = Size2D<f64, Pixels>;
A size expressed in Pixels

Aliased Type

#[repr(C)]
pub struct PixelsSize { pub width: f64, pub height: f64, }

Fields

width: f64

The extent of the element in the U units along the x axis (usually horizontal).

height: f64

The extent of the element in the U units along the y axis (usually vertical).