pub struct SelectionData { /* private fields */ }Implementations
Sourceimpl SelectionData
impl SelectionData
Sourcepub fn new(inner: impl HasSelectionData + 'static) -> Self
pub fn new(inner: impl HasSelectionData + 'static) -> Self
Create a new SelectionData
Sourcepub fn selection(&self) -> Option<TextSelection>
pub fn selection(&self) -> Option<TextSelection>
The selection inside a text control.
This is only populated for event targets that expose the text-control
selection APIs, such as input and textarea on the web. Some
selection events, notably selectstart, can also fire when selecting
normal document text. Those document selections are exposed by browser
APIs like document.getSelection() and intentionally return None here.