HasImageData

Trait HasImageData 

pub trait HasImageData: Any {
    // Required methods
    fn load_error(&self) -> bool;
    fn as_any(&self) -> &dyn Any;
}
A trait for any object that has the data for an image event

Required Methods

fn load_error(&self) -> bool

If the renderer encountered an error while loading the image

fn as_any(&self) -> &dyn Any

return self as Any

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl HasImageData for SerializedImageData

Available on crate feature serialize only.