HasTouchData

Trait HasTouchData 

pub trait HasTouchData: ModifiersInteraction + Any {
    // Required methods
    fn touches(&self) -> Vec<TouchPoint>;
    fn touches_changed(&self) -> Vec<TouchPoint>;
    fn target_touches(&self) -> Vec<TouchPoint>;
    fn as_any(&self) -> &dyn Any;
}

Required Methods

fn touches(&self) -> Vec<TouchPoint>

Get the touches that are currently down

fn touches_changed(&self) -> Vec<TouchPoint>

Get the touches that have changed since the last event

fn target_touches(&self) -> Vec<TouchPoint>

Get the touches that started and stayed on the element that triggered this event

fn as_any(&self) -> &dyn Any

return self as Any

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl HasTouchData for SerializedTouchData

Available on crate feature serialize only.